package RPM::Source::Convert::Plugins::R;
use strict;
use warnings;

use RPM::Source::Transformation::Factory;
use RPM::Source::Transformation::OptHandlerWrapper;

our @ISA=qw/RPM::Source::Transformation::Factory/;
push @RPM::Source::TransformContainer::FACTORY_CLASSES, __PACKAGE__;

our $verbose=0;

# see also https://docs.fedoraproject.org/en-US/packaging-guidelines/R/

sub transformations {
    return
	RPM::Source::Transformation::OptHandlerWrapper->new(
	    -priority => PRIORITY_CONVERT,
	    -name => 'generic_R_related_convert',
	    -opt_handler_sub=>\&opt_handler_R_convert),
	;
}

sub opt_handler_R_convert {
    my (undef,$spec,undef,$opt,$resourceobj)=@_;
    my ($rname,) = $resourceobj->datapath_get_resource_names();
    return RPM::Source::TransformContainer::TRANSFORMATION_OK if substr($rname, 0, 2) ne 'R-';

    my $macros=$spec->macros();
    my $mainsec=$spec->main_section;
    my $buildreq=$resourceobj->buildreq;
    my $has_exclude_arch;
    $mainsec->map_body(
	sub {
	    if (/^(\s*)ExcludeArch:(\s+)/i) {
		$_=$1.'ExcludeArch:'.$2.'%R_exclude_arches'."\n";
		$has_exclude_arch=1;
	    }
	});
    $mainsec->push_body('ExcludeArch: %R_exclude_arches'."\n") unless $has_exclude_arch;
    $buildreq->add_pre_buildreq('rpm-macros-R');
    #$buildreq->add_buildreq('R-base-devel');
    return RPM::Source::TransformContainer::TRANSFORMATION_OK;
}

1;
